<?php
/**
 * Plugin Filehtml (addon for plugin Adm_redacteurs)
 * Version  : 1.4 (2018/04/12)
 * Compatibility : Guppy v5.0+ et Adm_redacteurs v6.12+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require ADMR_HELPERS_PATH.'/manage_addons_writers_docs_helper.php';

class Manage_addons_writers_filehtml_helper extends Manage_addons_writers_docs_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_sort_options = array();	 // Options de tri
    protected $_addons = array();        // Tableau contenant les addons   
    protected $_writer_rights = array(); // Droits du rédacteur
    protected $_doc_infos = array('name' => 'filehtml', 'type' => 'filehtml'); // Tableau contenant les informations des documents (nom, type)

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct($writer_rights)
    {
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);

        parent :: __construct($this -> _writer_rights, $this -> _doc_infos);

//        $this -> CI -> load_addon_model('filehtml', 'writer_filehtml_model', array('id' => $this -> _params['writerid']));
        $this -> CI -> load_addon_model('filehtml', 'filehtml_ids_model');
    }
    
    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_writer_rights($writer_rights)
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;	// Droits du rédacteur         
    }
    
	// --------------------------------------------------------------------

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {
        parent :: manage();
    }
    
	// --------------------------------------------------------------------

	/**
	 * Active ou désactive les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
     * @param string action à appliquer (a = activation et i = désactivation)
	 * @return boolean
	 */
    protected function _activate_records_or_not($records_ids, $action)
    {
        return $this -> CI -> filehtml_ids_model -> update_status_by_id($records_ids, $action);
   //     return $this -> CI -> writer_filehtml_model -> update_status_by_id($records_ids, $action);
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return boolean
	 */
    protected function _delete_records($records_ids)
    {
        return $this -> CI -> filehtml_ids_model -> update_status_by_id($records_ids, 'd');
  //      return $this -> CI -> writer_filehtml_model -> delete_by_id($records_ids);
    }
    
	// --------------------------------------------------------------------

	/**
	 * valide les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return boolean
	 */
    protected function _validate_records($records_ids)
    {
        return $this -> CI -> filehtml_ids_model -> update_mode_by_id($records_ids, 0);
   //     return $this -> CI -> writer_filehtml_model -> update_mode_by_id($records_ids, 0);
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements du rédacteur
     * 
     * @access public
	 * @return string code html
	 */
    protected function _get_records()
    {
        $doc_ids = !empty($this -> _params['docid']) ? explode('-', $this -> _params['docid']) : NULL;
        
        return $this -> CI -> filehtml_ids_model -> get(array('author_id' => $this -> _params['writerid'], 'id' => $doc_ids, 'status' => array('a', 'i')), $this -> _params['sort']);    

       // return $this -> CI -> writer_filehtml_model -> get(array('id' => $doc_ids), $this -> _params['sort']);
    }
        
	// --------------------------------------------------------------------
  
	/**
	 * Renvoie le contenu de la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
     * @param object Modèle de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
    protected function _get_record_description($record)
    {
        return ($this -> _config['lang'][1] == ADMR_LNG) ? $record['title2'] : $record['title1'];       
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie l'url du lien du document dans la cellule intitulée "Description" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _build_href_for_td_description($record)
    {
        return Url_helper :: build_uri(
            $params = array_merge($this -> _params, array('id' => $record['id'])),
            $basehref = ADMR_BASE_HREF_PLUGIN.'&amp;ctrl=addons/filehtml/add_writers_filehtml'
        );
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule intitulée "Type" du tableau de données
     * 
	 * @access protected
	 * @param array Données du document
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_type($record)
	{
        return $this -> _lang['filehtml'];	
	}

	// --------------------------------------------------------------------

    public function search()
    {
        parent :: search();
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        $this -> _params = parent :: _set_params();
                
        return $this -> _params;
    }

	// --------------------------------------------------------------------

	/**
	 * synchronize les données des documents enregistrées pour le rédacteur avec ceux enregistrés dans le plugin filehtml
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    public function synchronize()
    {
 //       $this -> CI -> writer_filehtml_model -> synchronize($this -> CI -> filehtml_ids_model); // Synchronisation des enregistrements du rédacteur avec ceux de guppy

		parent :: synchronize();
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
/*    protected function set_sort_options()
    {
        return $this -> _sort_options = array('id_asc', 'id_desc', 'status_asc', 'status_desc', 'up_asc', 'up_desc');	// Options de tri         
    }
*/
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return parent :: set_title_page();
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_infos_page_content()
    {		
        return $this -> _lang['infos_page_manage_filehtml'];
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
     * @access public
     * @return string menu de la page
	 */	
    public function set_menu_plugin_items()
    {		
        $this -> CI -> load_helper('plugin_menu_for_writers_helper');
        
        if (ADMR_IS_ADMIN) {
            return Plugin_menu_helper :: set_admin_menu_items($this -> _lang, $this -> _config);    
        } else {
            return $this -> CI -> plugin_menu_for_writers_helper -> set_public_items('writers', $this -> _lang, $this -> _config, $this -> _writer_rights);         
        }  
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_header_addons()
    {
        return parent :: set_header_addons(); 
    }

} //End of Class